% demo: this is a demo script for SRWR
%
% Authors
%   * Jinhong Jung (jinhongjung@snu.ac.kr)
%   * Woojeong Jin (woojeong.jin@usc.edu)
%   * U Kang (ukang@snu.ac.kr)
%
% Reference
%   * Random Walk Based Ranking in Signed Social Networks: Model and Algorithms 
%   * Jinhong Jung, Woojung Jin, and U Kang
%   * Knowledge and Information Systems (KAIS), Springer (to appear)
%
%
% This software may be used only for research evaluation purposes.
% For other purposes (e.g., commercial), please contact the authors.

[A, n] = Import('data.tsv', 'tsv', 1);

% set parameters
c = 0.05;
epsilon = 1e-9;
beta = 0.5;
gamma = 0.5;
nIter = 300;

% SRWR-Iter
% do semi-normalization
[Ap, An] = SemiNormalize(A);

nQ = 100;
seeds = randi(n, nQ, 1);
times = zeros(nQ, 1);

for i = 1:nQ
   seed = seeds(i);
   tic;
   [rp_iter, rn_iter] = SRWRIter(Ap, An, seed, c, epsilon, beta, gamma, nIter);
   times(i) = toc;
end

fprintf('The average query time of SRWR-Iter:\t %.4f\n', mean(times));

% SRWR-Pre
[PREP] = SRWRPre(A, c, beta, gamma);

for i = 1:nQ
    seed = seeds(i);
    tic;
    [rp_pre, rn_pre] = SRWRQuery(seed, c, PREP);
    times(i) = toc;
end

fprintf('The average query time of SRWR-Pre:\t %.4f\n', mean(times));
