function [ A, n ] = Import( path, type, base)
% Import : load the data graph
%
% Parameters
%   * path : a path of the data
%   * type: a type of the file: csv or tsv
%   * base : node index base of the graph (0 or 1)
%
% Return values
%   * A : adjacency matrix of the graph
%   * n : # of nodes
%
% Authors
%   * Jinhong Jung (jinhongjung@snu.ac.kr)
%   * Woojeong Jin (woojung211@snu.ac.kr)
%   * U Kang (ukang@snu.ac.kr)
%
% This software is free of charge under research purposes.
% For commercial purposes, please contact the authors.

if nargin < 2
    type = 'csv';
end

if nargin < 3
    base = 0;
end

start_id = 1 - base;

if strcmp(type, 'csv')
    X = csvread(path);
elseif strcmp(type, 'tsv')
    X = dlmread(path);
end

X(:, 1) = X(:, 1) + start_id;
X(:, 2) = X(:, 2) + start_id;

if size(X, 2) < 3
   X = [X, ones(size(X, 1), 1)];
end


n = max(max( X(:, 1), X(:, 2) ));
A = sparse( X(:, 1), X(:, 2), X(:, 3), n, n);
if sum(sum(triu(abs(A), 1))) == 0 || sum(sum(tril(abs(A), -1))) == 0
    A = A + A';
end



end

